<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>WeChat Pay</title>
</head>

<body>
    <h1>Scan the below QR code with WeChat</h1>
    <img src="{{ wechatpay_qr }}" alt="WeChat QR Code">
</body>

</html>